@@ -47,7 +47,8 @@ class AuditTrailMixin:
                 data, self.audit.main_resource
             )
 
-        applications = self.request.jwt_auth.applicaties
+        jwt_auth = self.request.jwt_auth
+        applications = jwt_auth.applicaties
         if len(applications) > 1:
             logger.warning(
                 "Unexpectedly found %d applications, expected at most one",
@@ -61,25 +62,22 @@ class AuditTrailMixin:
             app_id = get_header(self.request, "X-NLX-Request-Application-Id")
             app_presentation = app_id  # we don't have any extra information...
 
-        user_id = self.request.jwt_auth.payload.get("user_id", "")
-        if not user_id:
-            user_id = get_header(self.request, "X-NLX-Request-User-Id") or ""
-
-        request_id = get_header(self.request, "X-NLX-Request-Id") or ""
+        user_id = jwt_auth.payload.get("user_id") or ""
+        user_representation = jwt_auth.payload.get("user_representation") or ""
 
         toelichting = get_header(self.request, "X-Audit-Toelichting") or ""
 
+        logrecord_id = get_header(self.request, "X-NLX-Logrecord-ID") or ""
+
         trail = AuditTrail(
             bron=self.audit.component_name,
-            request_id=request_id,
+            logrecord_id=logrecord_id,
             applicatie_id=app_id,
             applicatie_weergave=app_presentation,
             actie=action,
             actie_weergave=CommonResourceAction.labels.get(action, ""),
             gebruikers_id=user_id,
-            gebruikers_weergave=self.request.jwt_auth.payload.get(
-                "user_representation", ""
-            ),
+            gebruikers_weergave=user_representation,
             resultaat=status_code,
             hoofd_object=main_object,
             resource=self.basename,
@@ -197,7 +195,11 @@ class AuditTrailViewSet(NestedViewSetMixin, viewsets.ReadOnlyModelViewSet):
     main_resource_lookup_field = None  # Must be overwritten by subclasses
 
     def get_queryset(self):
+        if not self.kwargs:  # this happens during schema generation, and causes crashes
+            return self.queryset.all()
+
         qs = super().get_queryset()
+
         identifier = self.kwargs.get(self.main_resource_lookup_field)
         if identifier:
             filtered = qs.filter(hoofd_object__contains=identifier)
@@ -206,3 +208,9 @@ class AuditTrailViewSet(NestedViewSetMixin, viewsets.ReadOnlyModelViewSet):
             else:
                 raise Http404
         return qs
+
+    @property
+    def parent_lookup_kwargs(self):
+        return {
+            self.main_resource_lookup_field: "hoofd_object__contains",
+        }
