@@ -1,7 +1,7 @@
 import warnings
 
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .etags import calculate_etag
 
