@@ -1,5 +1,7 @@
 from django.db import models
 
+from rest_framework.response import Response
+
 
 def is_search_view(view):
     _action = getattr(view, "action", None)
@@ -27,4 +29,4 @@ class SearchMixin:
             return self.get_paginated_response(serializer.data)
 
         serializer = self.get_serializer(queryset, many=True)
-        return serializer.data
+        return Response(serializer.data)
